@@ -10,7 +10,7 @@ package Devel::Cover::Criterion;
 use strict;
 use warnings;
 
-our $VERSION = '1.26'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 use Devel::Cover::Statement;
 use Devel::Cover::Branch;
@@ -24,17 +24,18 @@ use Devel::Cover::Subroutine;
 use Devel::Cover::Time;
 use Devel::Cover::Pod;
 
-sub coverage    { $_[0][0] }
-sub information { $_[0][1] }
+sub coverage    { $_[0][0]                                        }
+sub information { $_[0][1]                                        }
 
-sub uncoverable { "n/a" }
-sub covered     { "n/a" }
-sub total       { "n/a" }
-sub percentage  { "n/a" }
-sub error       { "n/a" }
-sub text        { "n/a" }
-sub values      { [ $_[0]->covered ] }
-sub criterion   { require Carp; Carp::confess("criterion() must be overridden") }
+sub uncoverable { "n/a"                                           }
+sub covered     { "n/a"                                           }
+sub total       { "n/a"                                           }
+sub percentage  { "n/a"                                           }
+sub error       { "n/a"                                           }
+sub text        { "n/a"                                           }
+sub values      { [ $_[0]->covered ]                              }
+sub criterion   { require Carp;
+                  Carp::confess("criterion() must be overridden") }
 
 sub calculate_percentage {
     my $class = shift;
@@ -76,7 +77,7 @@ Devel::Cover::Criterion - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
