@@ -10,44 +10,41 @@ package Devel::Cover::DB::IO::JSON;
 use strict;
 use warnings;
 
-use Fcntl ":flock";
+use base "Devel::Cover::DB::IO::Base";
+
 use JSON::MaybeXS ();
 
-our $VERSION = '1.26'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 sub new {
     my $class = shift;
     my %args = @_;
-
     my $json = JSON::MaybeXS->new(utf8 => 1, allow_blessed => 1);
-    $json->ascii->pretty->canonical if exists $args{options} && $args{options} =~ /\bpretty\b/i;
-
-    bless \$json, $class
+    $json->ascii->pretty->canonical
+        if exists $args{options} && $args{options} =~ /\bpretty\b/i;
+    my $self = $class->SUPER::new(%args, json => $json);
+    bless $self, $class
 }
 
 sub read {
     my $self   = shift;
     my ($file) = @_;
-
-    open my $fh, "<", $file or die "Can't open $file: $!\n";
-    flock $fh, LOCK_SH      or die "Can't lock $file: $!\n";
-    local $/;
-    my $data = eval { ${$self}->decode(<$fh>) };
-    die "Can't read $file with ".(ref ${$self}).": $@" if $@;
-    close $fh or die "Can't close $file: $!\n";
-    $data
+    $self->_read_fh($file, sub {
+        my ($fh) = @_;
+        local $/;
+        my $data = eval { $self->{json}->decode(<$fh>) };
+        die "Can't read $file with ", (ref $self->{json}), ": $@" if $@;
+        $data
+    })
 }
 
 sub write {
     my $self = shift;
     my ($data, $file) = @_;
-
-    unlink $file;
-    open my $fh, ">", $file or die "Can't open $file: $!\n";
-    flock $fh, LOCK_EX      or die "Can't lock $file: $!\n";
-    print $fh ${$self}->encode($data);
-    close $fh or die "Can't close $file: $!\n";
-    $self
+    $self->_write_fh($file, sub {
+        my ($fh) = @_;
+        print $fh $self->{json}->encode($data);
+    })
 }
 
 1
@@ -60,7 +57,7 @@ Devel::Cover::DB::IO::JSON - JSON based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
