@@ -10,29 +10,28 @@ package Devel::Cover::DB::IO::Storable;
 use strict;
 use warnings;
 
+use base "Devel::Cover::DB::IO::Base";
+
 use Storable;
 
-our $VERSION = '1.26'; # VERSION
+our $VERSION = '1.27'; # VERSION
 
 sub new {
     my $class = shift;
-    my $self  = { @_ };
+    my $self = $class->SUPER::new(@_);
     bless $self, $class
 }
 
 sub read {
     my $self   = shift;
     my ($file) = @_;
-    Storable::lock_retrieve($file)
+    $self->_read($file, sub { Storable::retrieve($file) })
 }
 
 sub write {
     my $self = shift;
     my ($data, $file) = @_;
-
-    unlink $file;
-    Storable::lock_nstore($data, $file);
-    $self
+    $self->_write($file, sub { Storable::nstore($data, $file) })
 }
 
 1
@@ -45,7 +44,7 @@ Devel::Cover::DB::IO::Storable - Storable based IO routines for Devel::Cover::DB
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
