@@ -8,8 +8,15 @@ use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
 use Devel::Cover::Truth_Table;
 
-our $VERSION = '1.26'; # VERSION
-our $LVERSION = do { eval '$VERSION' || "0.001" };  # for development purposes
+our $VERSION;
+BEGIN {
+our $VERSION = '1.27'; # VERSION
+}
+
+use Devel::Cover::Inc;
+
+BEGIN { $VERSION //= $Devel::Cover::Inc::VERSION }
+
 
 #-------------------------------------------------------------------------------
 # Subroutine : get_coverage_for_line
@@ -263,8 +270,8 @@ sub print_html_header {
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml">
 <!--
-This file was generated by Devel::Cover Version $LVERSION
-Devel::Cover is copyright 2001-2012, Paul Johnson (paul\@pjcj.net)
+This file was generated by Devel::Cover Version $VERSION
+Devel::Cover is copyright 2001-2017, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -431,7 +438,6 @@ END_HTML
     close($fh) or warn "Unable to close '$outfile' [$!]";
 
     print "HTML output written to $outfile\n" unless $options->{silent};
-
 }
 
 
@@ -730,7 +736,6 @@ sub report {
     %Filenames = map {$_ => do {(my $f = $_) =~ s/\W/-/g; $f}} @files;
 
     print_stylesheet($db, $opt);
-    print_summary_report($db, $opt);
     for my $file (@files) {
         print_file_report($db, $file, $opt);
         unless ($opt->{option}{unified}) {
@@ -739,6 +744,7 @@ sub report {
             print_sub_report       ($db, $file, $opt) if $opt->{show}{subroutine};
         }
     }
+    print_summary_report($db, $opt);
 
     print "done.\n" unless $opt->{silent};
 }
@@ -751,7 +757,7 @@ Devel::Cover::Report::Html_minimal - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.26
+version 1.27
 
 =head1 SYNOPSIS
 
